
API Documentation
=================

Core Pricing Infrastructure
---------------------------

.. toctree::

    tendril.pricing.base
    tendril.pricing.structured
    tendril.pricing.collector


Price Modifiers
---------------

.. toctree::

    tendril.pricing.addons
    tendril.pricing.discount
    tendril.pricing.tax
    tendril.pricing.gst

